<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link  https://rextheme.com
 * @since 1.0.0
 *
 * @package    Checkout_Field_Editor
 * @subpackage Checkout_Field_Editor/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Checkout_Field_Editor
 * @subpackage Checkout_Field_Editor/includes
 * @author     CodeRex <enquiry@coderex.co>
 */
class Checkout_Field_Editor {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since  1.0.0
	 * @access protected
	 * @var    Checkout_Field_Editor_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since  1.0.0
	 * @access protected
	 * @var    string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since  1.0.0
	 * @access protected
	 * @var    string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 * 
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		if ( defined( 'CHECKOUT_FIELD_EDITOR_VERSION' ) ) {
			$this->version = CHECKOUT_FIELD_EDITOR_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'checkout-field-editor';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Checkout_Field_Editor_Loader. Orchestrates the hooks of the plugin.
	 * - Checkout_Field_Editor_i18n. Defines internationalization functionality.
	 * - Checkout_Field_Editor_Admin. Defines all hooks for the admin area.
	 * - Checkout_Field_Editor_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since  1.0.0
	 * @access private
	 */
	private function load_dependencies() {

		/**
         * The class responsible for auto loading all files of the
         * core plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'vendor/autoload.php';

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-checkout-field-editor-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-checkout-field-editor-i18n.php';

		$this->loader = new Checkout_Field_Editor_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Checkout_Field_Editor_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since  1.0.0
	 * @access private
	 */
	private function set_locale() {

		$plugin_i18n = new Checkout_Field_Editor_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since  1.0.0
	 * @access private
	 */
	private function define_admin_hooks() { 

		$plugin_admin = new Checkout_Field_Editor_Admin( $this->get_plugin_name(), $this->get_version() );
		$plugins = get_option('active_plugins');

		if( in_array('woocommerce/woocommerce.php',$plugins)){

			$this->loader->add_action( 'admin_init', $plugin_admin, 'cfe_admin_redirect' );
			$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
			$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
			$this->loader->add_action( 'admin_menu', $plugin_admin, 'cfe_admin_menu' );
			$this->loader->add_action('wp_ajax_cfe_delete',$plugin_admin,'cfe_delete_data');
			$this->loader->add_action('wp_ajax_cfe_add',$plugin_admin,'cfe_add_data');
			$this->loader->add_action('wp_ajax_cfe_edit',$plugin_admin,'cfe_update_data');
			$this->loader->add_action('wp_ajax_cfe_restore_default',$plugin_admin,'cfe_restore_default');
			$this->loader->add_action('wp_ajax_cfe_wc_edit_field',$plugin_admin,'cfe_wc_edit_field');
			
			$this->loader->add_action('wp_ajax_cfe_change_required_option',$plugin_admin,'cfe_change_required_option');
			$this->loader->add_action('wp_ajax_cfe_change_enable_option',$plugin_admin,'cfe_change_enable_option');
			$this->loader->add_action('wp_ajax_cfe_change_show_option',$plugin_admin,'cfe_change_show_option');
		}
		// }else{
		// 	$this->loader->add_action( 'admin_notices', $plugin_admin, 'admin_notice_for_premium' );
		// }

		
	
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since  1.0.0
	 * @access private
	 */
	private function define_public_hooks() {

		$plugin_public = new Checkout_Field_Editor_Public( $this->get_plugin_name(), $this->get_version() );
		

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action('woocommerce_after_order_notes',$plugin_public,'cfe_add_custom_checkout_field',999);
		$this->loader->add_action('woocommerce_checkout_update_order_meta',$plugin_public,'cfe_custom_checkout_field_update_order_meta');
		$this->loader->add_action('woocommerce_admin_order_data_after_billing_address',$plugin_public,'cfe_display_additional_field_custom');
		$this->loader->add_action('woocommerce_admin_order_data_after_billing_address',$plugin_public,'cfe_display_billing_field_custom');
		$this->loader->add_action('woocommerce_admin_order_data_after_shipping_address',$plugin_public,'cfe_display_shipping_field_custom');
		$this->loader->add_action('woocommerce_checkout_fields',$plugin_public,'cfe_add_fields',999);
		// $this->loader->add_action('woocommerce_checkout_fields',$plugin_public,'cfe_custom_override_order_fields');
		$this->loader->add_action('woocommerce_checkout_process',$plugin_public,'cfe_custom_checkout_field_process');
		



	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since 1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since  1.0.0
	 * @return string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since  1.0.0
	 * @return Checkout_Field_Editor_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since  1.0.0
	 * @return string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
